@@ -50,6 +50,9 @@
 
 #include "Python.h"
 
+#if Win32
+#include <winsock2.h>
+#endif
 
 #include <R.h>
 #include <Rinternals.h>
@@ -73,12 +76,6 @@
 
 //#define RPY_VERBOSE
 
-#if Win32
-#if !defined(uintptr_t)
-typedef unsigned int *uintptr_t;
-#endif
-extern __declspec(dllimport) uintptr_t R_CStackLimit; /* C stack limit */
-#endif
 
 
 
@@ -1887,6 +1884,12 @@ EnvironmentSexp_findVar(PyObject *self, PyObject *args, PyObject *kwds)
     return NULL;
   }
 
+  if (strlen(name) == 0) {
+    PyErr_Format(PyExc_ValueError, "Invalid name.");
+    Py_DECREF(Py_False);
+    return NULL;
+  }
+
   if (rho_R == R_EmptyEnv) {
     PyErr_Format(PyExc_LookupError, "Fatal error: R_EmptyEnv.");
   }
@@ -1896,12 +1899,13 @@ EnvironmentSexp_findVar(PyObject *self, PyObject *args, PyObject *kwds)
   } else {
     res_R = findVar(install(name), rho_R);
   }
-
+  
   if (res_R != R_UnboundValue) {
     //FIXME rpy_only
     res = newPySexpObject(res_R);
   } else {
     PyErr_Format(PyExc_LookupError, "'%s' not found", name);
+    Py_DECREF(Py_False);
     res = NULL;
   }
   Py_DECREF(Py_False);
@@ -1978,6 +1982,12 @@ EnvironmentSexp_subscript(PyObject *self, PyObject *key)
     PyErr_Format(PyExc_ValueError, "NULL SEXP.");
     return NULL;
   }
+
+  if (strlen(name) == 0) {
+    PyErr_Format(PyExc_ValueError, "Invalid name.");
+    return NULL;
+  }
+
   res_R = findVarInFrame(rho_R, install(name));
 
   if (res_R != R_UnboundValue) {
