@@ -43,6 +43,8 @@ class SexpEnvironmentTestCase(unittest.TestCase):
         ok = isinstance(sfit_R, rinterface.SexpClosure)
         self.assertTrue(ok)
 
+    def testGetEmptyString(self):
+        self.assertRaises(ValueError, rinterface.globalEnv.get, "")
 
     def testGet_functionOnly_lookupError(self):
         # now with the function-only option
@@ -68,6 +70,9 @@ class SexpEnvironmentTestCase(unittest.TestCase):
         ok = ge.get("identical")(obj, a)
         self.assertTrue(ok[0])
 
+    def testSubscriptEmptyString(self):
+        self.assertRaises(ValueError, rinterface.globalEnv.__getitem__, "")
+
     def testLength(self):
         newEnv = rinterface.globalEnv.get("new.env")
         env = newEnv()
